#ifndef TPETRATSQR_CONFIG_H
#define TPETRATSQR_CONFIG_H

/* Define if building TSQR with std::complex<T> support */
/* #undef HAVE_KOKKOSTSQR_COMPLEX */

/* Define if the TBB (Intel Threading Building Blocks) TPL is available */
/* #undef HAVE_KOKKOSTSQR_TBB */

#endif // TPETRATSQR_CONFIG_H
